==> xwidgetsbase-9.1.2.tar.gz: lib/XWidgets/XDD/XDropSearch.dart <==
part of xwidgetbase;

class XDropSearch<T> extends StatefulWidget {
  XDropSearch({
    Key? key,
    required this.itemSelected,
    required this.liItems,
    required this.label,
    required this.onChanged_ItemOfDD,
    this.label_Color,
    this.background_Color = Colors.transparent,
    this.itemWidgetBuilder,
    this.clearBTN,
    this.itemAsString,
    this.onFind,
    this.focusColorOfDD,
    this.menu_SearchBox_Active,
    this.clearBTN_Active,
    this.contentPadding,
    this.dropdownBuilder,
    this.item_TextStyle,
    this.item_TextAlignment,
    this.label_Style,
    this.autoValidateMode = AutovalidateMode.disabled,
    this.clearBTN_IconSize,
    this.clearBTN_Padding,
    this.clearBTN_IconColor,
    this.clearBTN_Constraints,
    this.menu_BackGroundColor,
    this.menu_Title,
    this.menu_Title_Color,
    this.menu_Title_Style,
    this.menu_SearchBoxBorderANDtitle_Color,
    this.al_BackGroundColor,
    this.al_Title,
    this.al_Title_Color,
    this.al_Title_Style,
    this.al_SearchBox_Active,
    this.al_SearchBoxBorderANDtitle_Color,
    this.dropBTN,
    this.dropBTN_Padding,
    this.dropBTN_IconColor,
    this.dropBTN_IconSize = 18,
    this.dropBTN_Constraints,
    this.labelANDborder_Color,
    this.label_Behavior,
    this.propToShowInItems,
    this.dropDownMode,
    this.validator,
  }) : super(key: key);
  T? itemSelected;
  final List<T> liItems;
  final String? label;
  final ValueChanged? onChanged_ItemOfDD;
  final String Function(T)? itemAsString;
  final Color? background_Color;
  final Widget Function(BuildContext, T?)? dropdownBuilder;
  final EdgeInsetsGeometry? contentPadding;
  final TextStyle? label_Style;
  final Color? label_Color;
  final Color? labelANDborder_Color;
  final FloatingLabelBehavior? label_Behavior; //TODO da vedere il naming
  final bool? clearBTN_Active;
  final Widget? clearBTN;
  final Color? clearBTN_IconColor;
  final double? clearBTN_IconSize;
  final BoxConstraints? clearBTN_Constraints;
  final EdgeInsetsGeometry? clearBTN_Padding;
  final Widget? dropBTN;
  final Color? dropBTN_IconColor;
  final double? dropBTN_IconSize;
  final BoxConstraints? dropBTN_Constraints;
  final EdgeInsetsGeometry? dropBTN_Padding;
  final String? menu_Title;
  final TextStyle? menu_Title_Style;
  final Color? menu_Title_Color;
  final Color? menu_BackGroundColor;
  final bool? menu_SearchBox_Active;
  final Color? menu_SearchBoxBorderANDtitle_Color;
  final String? al_Title;
  final TextStyle? al_Title_Style;
  final Color? al_Title_Color;
  final Color? al_BackGroundColor;
  final bool? al_SearchBox_Active;
  final Color? al_SearchBoxBorderANDtitle_Color;
  final DropdownSearchPopupItemBuilder<T>? itemWidgetBuilder;
  final TextStyle? item_TextStyle;
  final Alignment? item_TextAlignment;

  ///Metti "Menu" per cliccare sul drop down e avere la lista a discesa / oppure setta "Dialog" per avere un alertDialog per visualizzare la lista
  String? dropDownMode;
  String? Function(T?)? validator;
  final String? propToShowInItems;
  final Future<List<T>> Function(String)? onFind;
  final AutovalidateMode? autoValidateMode;
  final Color? focusColorOfDD;

  @override
  _XDropSearchState<T> createState() => _XDropSearchState<T>();
}

class _XDropSearchState<T> extends State<XDropSearch<T>> {
  DropdownSearch<T>? internalDDwidget;
  @override
  void initState() {
    super.initState();
  }

  xBuilder_Menu() {
    return PopupProps.menu(
        searchFieldProps: TextFieldProps(
          decoration: inputDecorationDD_searchBox(colorBorderANDlabelForSearchBox: widget.menu_SearchBoxBorderANDtitle_Color),
        ),
        menuProps: MenuProps(backgroundColor: widget.menu_BackGroundColor ?? widget.al_BackGroundColor ?? widget.background_Color ?? Colors.grey[900]),
        fit: FlexFit.loose,
        showSearchBox: widget.menu_SearchBox_Active ?? true,
        title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7, bottom: 7), child: Text(widget.menu_Title ?? widget.label ?? "<No Title>", style: widget.menu_Title_Style ?? XStyles.xStyTextForDescr(widget.menu_Title_Color ?? Colors.blue[300])))]),
        itemBuilder: widget.itemWidgetBuilder != null
            ? widget.itemWidgetBuilder
            : ((context, item, isSelected) {
                return Card(child: Container(height: 35, margin: EdgeInsets.only(left: 7), alignment: widget.item_TextAlignment ?? Alignment.centerLeft, child: Text(widget.itemAsString != null ? item : (item as dynamic)[widget.propToShowInItems!], style: widget.item_TextStyle ?? XStyles.xStyTextForDescr(widget.menu_Title_Color ?? Colors.white))));
              }));
  }

  xBuilder_Dialog() {
    return PopupProps.dialog(
      searchFieldProps: TextFieldProps(decoration: inputDecorationDD_searchBox(colorBorderANDlabelForSearchBox: widget.al_SearchBoxBorderANDtitle_Color)),
      fit: FlexFit.loose,
      showSearchBox: widget.al_SearchBox_Active ?? true,
      title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7), child: Text(widget.al_Title ?? widget.label ?? "<No Title>", style: widget.al_Title_Style ?? XStyles.xStyTextForDescr(widget.al_Title_Color ?? widget.al_SearchBoxBorderANDtitle_Color ?? Colors.blue[300])))]),
      dialogProps: DialogProps(backgroundColor: widget.al_BackGroundColor ?? widget.menu_BackGroundColor ?? widget.background_Color ?? Colors.grey[900]),
      itemBuilder: widget.itemWidgetBuilder != null
          ? widget.itemWidgetBuilder
          : ((context, item, isSelected) {
              return Card(child: Container(height: 35, margin: EdgeInsets.only(left: 7), alignment: widget.item_TextAlignment ?? Alignment.center, child: Text(widget.itemAsString != null ? item : (item as dynamic)[widget.propToShowInItems!], style: widget.item_TextStyle ?? XStyles.xStyTextForDescr(widget.al_Title_Color ?? Colors.white))));
            }),
    );
  }

  @override
  Widget build(BuildContext context) {
    internalDDwidget = DropdownSearch<T>(
        asyncItems: widget.onFind,
        autoValidateMode: widget.autoValidateMode,
        validator: widget.validator,
        dropdownButtonProps: DropdownButtonProps(
          color: widget.background_Color,
          iconSize: widget.dropBTN_IconSize!,
          constraints: widget.dropBTN_Constraints ?? BoxConstraints(maxWidth: 30, minWidth: 30),
          padding: widget.dropBTN_Padding ?? EdgeInsets.all(5),
          icon: widget.dropBTN ?? Icon(Icons.arrow_downward_sharp, color: widget.dropBTN_IconColor ?? Colors.white, size: widget.dropBTN_IconSize),
        ),
        dropdownDecoratorProps: DropDownDecoratorProps(
            dropdownSearchDecoration: InputDecoration(
          contentPadding: widget.contentPadding ?? EdgeInsets.only(left: 5),
          hintText: "",
          floatingLabelBehavior: widget.label_Behavior ?? FloatingLabelBehavior.always,
          label: Text(widget.label ?? "", style: widget.label_Style ?? XStyles.xStyTextForLabel(widget.labelANDborder_Color ?? widget.label_Color ?? Colors.grey[500])),
          fillColor: widget.background_Color,
          focusColor: widget.focusColorOfDD,
          filled: true,
          labelStyle: widget.label_Style ?? XStyles.xStyTextForLabel(widget.labelANDborder_Color ?? widget.label_Color ?? Colors.grey[500]),
          hintStyle: XStyles.xStyTextForSubLabel(widget.labelANDborder_Color ?? widget.label_Color ?? Color.fromARGB(255, 189, 189, 189)),
          border: inputDecorationForDD(widget.labelANDborder_Color ?? Colors.grey[500]),
          disabledBorder: inputDecorationForDD(widget.labelANDborder_Color ?? Colors.grey[500]),
          enabledBorder: inputDecorationForDD(widget.labelANDborder_Color ?? Colors.grey[500]),
        )),
        popupProps: widget.dropDownMode != null
            ? (widget.dropDownMode == "Dialog" ? xBuilder_Dialog() : xBuilder_Menu()) //
            : (MediaQuery.of(context).size.width > 800 ? xBuilder_Menu() : xBuilder_Dialog()),
        items: widget.liItems,
        selectedItem: widget.itemSelected,
        clearButtonProps: ClearButtonProps(
          padding: widget.clearBTN_Padding ?? EdgeInsets.all(5),
          icon: widget.clearBTN ?? Icon(Icons.clear, color: widget.clearBTN_IconColor ?? Colors.white, size: widget.clearBTN_IconSize),
          isVisible: widget.clearBTN_Active ?? widget.itemSelected != null || widget.itemSelected != "" || widget.itemSelected != " " ? true : false,
          constraints: widget.clearBTN_Constraints ?? BoxConstraints(maxWidth: 30, minWidth: 30),
        ),
        onChanged: (value) {
          widget.onChanged_ItemOfDD!(value);
        },
        itemAsString: widget.itemAsString != null
            ? widget.itemAsString
            : (i) {
                if (i == null) {
                  if (widget.propToShowInItems == null) {
                    return "";
                  } else {
                    return (i as dynamic)[widget.propToShowInItems];
                  }
                } else {
                  return i.toString();
                }
              },
        dropdownBuilder: widget.dropdownBuilder);
    return Container(child: internalDDwidget!);
  }

  inputDecorationForDD(Color? colorBorder) {
    return OutlineInputBorder(borderSide: BorderSide(color: colorBorder ?? Colors.white));
  }

  inputDecorationDD_btn({Color? colorBorderANDlabel}) {
    return InputDecoration(
      isCollapsed: true,
      labelStyle: XStyles.xStyTextForDescr(colorBorderANDlabel ?? Colors.white),
      border: inputDecorationForDD(colorBorderANDlabel ?? Colors.white),
      disabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Colors.white),
      enabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Colors.white),
    );
  }

  inputDecorationDD_searchBox({Color? colorBorderANDlabelForSearchBox}) {
    return InputDecoration(
      hintText: "cerca...",
      labelStyle: XStyles.xStyTextForSubDescr(colorBorderANDlabelForSearchBox),
      hintStyle: XStyles.xStyTextForDescr(colorBorderANDlabelForSearchBox ?? Colors.white),
      border: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.white),
      disabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.white),
      enabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.white),
    );
  }
}

==> xwidgetsbase-9.6.9.tar.gz: lib/XWidgets/XDD/XDropSearch.dart <==
part of xwidgetbase;

class XDropSearch<T> extends StatefulWidget {
  XDropSearch({
    Key? key,
    required this.itemSelected,
    required this.liItems,
    required this.label,
    required this.onChanged_ItemOfDD,
    this.label_Color,
    this.background_Color = Colors.transparent,
    this.itemWidgetBuilder,
    this.clearBTN,
    this.itemAsString,
    this.onFind,
    this.focusColorOfDD,
    this.menu_SearchBox_Active,
    this.clearBTN_Active,
    this.contentPadding,
    this.dropdownBuilder,
    this.item_TextStyle,
    this.item_TextAlignment,
    this.label_Style,
    this.autoValidateMode = AutovalidateMode.disabled,
    this.clearBTN_IconSize,
    this.clearBTN_Padding,
    this.clearBTN_IconColor,
    this.clearBTN_Constraints,
    this.menu_BackGroundColor,
    this.menu_Title,
    this.menu_Title_Color,
    this.menu_Title_Style,
    this.menu_SearchBoxBorderANDtitle_Color,
    this.al_BackGroundColor,
    this.al_Title,
    this.al_Title_Color,
    this.al_Title_Style,
    this.al_SearchBox_Active,
    this.al_SearchBoxBorderANDtitle_Color,
    this.dropBTN,
    this.dropBTN_Padding,
    this.dropBTN_IconColor,
    this.dropBTN_IconSize = 18,
    this.dropBTN_Constraints,
    this.labelANDborder_Color,
    this.label_Behavior,
    this.propToShowInItems,
    this.dropDownMode,
    this.validator,
  }) : super(key: key);
  T? itemSelected;
  final List<T> liItems;
  final String? label;
  final ValueChanged? onChanged_ItemOfDD;
  final String Function(T)? itemAsString;
  final Color? background_Color;
  final Widget Function(BuildContext, T?)? dropdownBuilder;
  final EdgeInsetsGeometry? contentPadding;
  final TextStyle? label_Style;
  final Color? label_Color;
  final Color? labelANDborder_Color;
  final FloatingLabelBehavior? label_Behavior; //TODO da vedere il naming
  final bool? clearBTN_Active;
  final Widget? clearBTN;
  final Color? clearBTN_IconColor;
  final double? clearBTN_IconSize;
  final BoxConstraints? clearBTN_Constraints;
  final EdgeInsetsGeometry? clearBTN_Padding;
  final Widget? dropBTN;
  final Color? dropBTN_IconColor;
  final double? dropBTN_IconSize;
  final BoxConstraints? dropBTN_Constraints;
  final EdgeInsetsGeometry? dropBTN_Padding;
  final String? menu_Title;
  final TextStyle? menu_Title_Style;
  final Color? menu_Title_Color;
  final Color? menu_BackGroundColor;
  final bool? menu_SearchBox_Active;
  final Color? menu_SearchBoxBorderANDtitle_Color;
  final String? al_Title;
  final TextStyle? al_Title_Style;
  final Color? al_Title_Color;
  final Color? al_BackGroundColor;
  final bool? al_SearchBox_Active;
  final Color? al_SearchBoxBorderANDtitle_Color;
  final DropdownSearchPopupItemBuilder<T>? itemWidgetBuilder;
  final TextStyle? item_TextStyle;
  final Alignment? item_TextAlignment;

  ///Metti "Menu" per cliccare sul drop down e avere la lista a discesa / oppure setta "Dialog" per avere un alertDialog per visualizzare la lista
  String? dropDownMode;
  String? Function(T?)? validator;
  final String? propToShowInItems;
  final Future<List<T>> Function(String)? onFind;
  final AutovalidateMode? autoValidateMode;
  final Color? focusColorOfDD;

  @override
  _XDropSearchState<T> createState() => _XDropSearchState<T>();
}

class _XDropSearchState<T> extends State<XDropSearch<T>> {
  DropdownSearch<T>? internalDDwidget;
  @override
  void initState() {
    super.initState();
  }

  xBuilder_Menu() {
    return PopupProps.menu(
        searchFieldProps: TextFieldProps(
          decoration: inputDecorationDD_searchBox(colorBorderANDlabelForSearchBox: widget.menu_SearchBoxBorderANDtitle_Color),
        ),
        menuProps: MenuProps(backgroundColor: widget.menu_BackGroundColor ?? widget.al_BackGroundColor ?? widget.background_Color ?? Colors.grey[900]),
        fit: FlexFit.loose,
        showSearchBox: widget.menu_SearchBox_Active ?? true,
        title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7, bottom: 7), child: Text(widget.menu_Title ?? widget.label ?? "<No Title>", style: widget.menu_Title_Style ?? XStyles.xStyTextForDescr(widget.menu_Title_Color ?? Colors.blue[300])))]),
        itemBuilder: widget.itemWidgetBuilder != null
            ? widget.itemWidgetBuilder
            : ((context, item, isSelected) {
                return Card(child: Container(height: 35, margin: EdgeInsets.only(left: 7), alignment: widget.item_TextAlignment ?? Alignment.centerLeft, child: Text(widget.itemAsString != null ? item.toString() : (item as dynamic)[widget.propToShowInItems!], style: widget.item_TextStyle ?? XStyles.xStyTextForDescr(widget.menu_Title_Color ?? Colors.white))));
              }));
  }

  xBuilder_Dialog() {
    return PopupProps.dialog(
      searchFieldProps: TextFieldProps(decoration: inputDecorationDD_searchBox(colorBorderANDlabelForSearchBox: widget.al_SearchBoxBorderANDtitle_Color)),
      fit: FlexFit.loose,
      showSearchBox: widget.al_SearchBox_Active ?? true,
      title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7), child: Text(widget.al_Title ?? widget.label ?? "<No Title>", style: widget.al_Title_Style ?? XStyles.xStyTextForDescr(widget.al_Title_Color ?? widget.al_SearchBoxBorderANDtitle_Color ?? Colors.blue[300])))]),
      dialogProps: DialogProps(backgroundColor: widget.al_BackGroundColor ?? widget.menu_BackGroundColor ?? widget.background_Color ?? Colors.grey[900]),
      itemBuilder: widget.itemWidgetBuilder != null
          ? widget.itemWidgetBuilder
          : ((context, item, isSelected) {
              return Card(child: Container(height: 35, margin: EdgeInsets.only(left: 7), alignment: widget.item_TextAlignment ?? Alignment.center, child: Text(widget.itemAsString != null ? item.toString() : (item as dynamic)[widget.propToShowInItems!], style: widget.item_TextStyle ?? XStyles.xStyTextForDescr(widget.al_Title_Color ?? Colors.white))));
            }),
    );
  }

  @override
  Widget build(BuildContext context) {
    internalDDwidget = DropdownSearch<T>(
        asyncItems: widget.onFind,
        autoValidateMode: widget.autoValidateMode,
        validator: widget.validator,
        dropdownButtonProps: DropdownButtonProps(
          color: widget.background_Color,
          iconSize: widget.dropBTN_IconSize!,
          constraints: widget.dropBTN_Constraints ?? BoxConstraints(maxWidth: 30, minWidth: 30),
          padding: widget.dropBTN_Padding ?? EdgeInsets.all(5),
          icon: widget.dropBTN ?? Icon(Icons.arrow_downward_sharp, color: widget.dropBTN_IconColor ?? Colors.white, size: widget.dropBTN_IconSize),
        ),
        dropdownDecoratorProps: DropDownDecoratorProps(
            dropdownSearchDecoration: InputDecoration(
          contentPadding: widget.contentPadding ?? EdgeInsets.only(left: 5),
          hintText: "",
          floatingLabelBehavior: widget.label_Behavior ?? FloatingLabelBehavior.always,
          label: Text(widget.label ?? "", style: widget.label_Style ?? XStyles.xStyTextForLabel(widget.labelANDborder_Color ?? widget.label_Color ?? Colors.grey[500])),
          fillColor: widget.background_Color,
          focusColor: widget.focusColorOfDD,
          filled: true,
          labelStyle: widget.label_Style ?? XStyles.xStyTextForLabel(widget.labelANDborder_Color ?? widget.label_Color ?? Colors.grey[500]),
          hintStyle: XStyles.xStyTextForSubLabel(widget.labelANDborder_Color ?? widget.label_Color ?? Color.fromARGB(255, 189, 189, 189)),
          border: inputDecorationForDD(widget.labelANDborder_Color ?? Colors.grey[500]),
          disabledBorder: inputDecorationForDD(widget.labelANDborder_Color ?? Colors.grey[500]),
          enabledBorder: inputDecorationForDD(widget.labelANDborder_Color ?? Colors.grey[500]),
        )),
        popupProps: widget.dropDownMode != null
            ? (widget.dropDownMode == "Dialog" ? xBuilder_Dialog() : xBuilder_Menu()) //
            : (MediaQuery.of(context).size.width > 800 ? xBuilder_Menu() : xBuilder_Dialog()),
        items: widget.liItems,
        selectedItem: widget.itemSelected,
        clearButtonProps: ClearButtonProps(
          padding: widget.clearBTN_Padding ?? EdgeInsets.all(5),
          icon: widget.clearBTN ?? Icon(Icons.clear, color: widget.clearBTN_IconColor ?? Colors.white, size: widget.clearBTN_IconSize),
          isVisible: widget.clearBTN_Active ?? widget.itemSelected != null || widget.itemSelected != "" || widget.itemSelected != " " ? true : false,
          constraints: widget.clearBTN_Constraints ?? BoxConstraints(maxWidth: 30, minWidth: 30),
        ),
        onChanged: (value) {
          widget.onChanged_ItemOfDD!(value);
        },
        itemAsString: widget.itemAsString != null
            ? widget.itemAsString
            : (i) {
                if (i == null) {
                  if (widget.propToShowInItems == null) {
                    return "";
                  } else {
                    return (i as dynamic)[widget.propToShowInItems];
                  }
                } else {
                  return i.toString();
                }
              },
        dropdownBuilder: widget.dropdownBuilder);
    return Container(child: internalDDwidget!);
  }

  inputDecorationForDD(Color? colorBorder) {
    return OutlineInputBorder(borderSide: BorderSide(color: colorBorder ?? Colors.white));
  }

  inputDecorationDD_btn({Color? colorBorderANDlabel}) {
    return InputDecoration(
      isCollapsed: true,
      labelStyle: XStyles.xStyTextForDescr(colorBorderANDlabel ?? Colors.white),
      border: inputDecorationForDD(colorBorderANDlabel ?? Colors.white),
      disabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Colors.white),
      enabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Colors.white),
    );
  }

  inputDecorationDD_searchBox({Color? colorBorderANDlabelForSearchBox}) {
    return InputDecoration(
      hintText: "cerca...",
      labelStyle: XStyles.xStyTextForSubDescr(colorBorderANDlabelForSearchBox),
      hintStyle: XStyles.xStyTextForDescr(colorBorderANDlabelForSearchBox ?? Colors.white),
      border: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.white),
      disabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.white),
      enabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.white),
    );
  }
}
